C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_LSWAP     SWAP ARRAY BASED ON SORT INDICES - LOGICAL
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-02-11
C
C ABSTRACT: SWAP ARRAY ELEMENTS AROUND TO MATCH INDICES CREATED BY
C   BY A SORT -- FOR LOGICAL ARRAYS.
C
C PROGRAM HISTORY LOG:
C   00-02-11  M. BARTH    ORIGINAL VERSION
C   02-05-29  M. BARTH    RESTRUCTURED TEMPORARY MEMORY ARRAY USAGE
C   08-06-19  L. BENJAMIN CHANGED TEMPORARY MEMORY TO BE PASSED IN
C                         INSTEAD OF CALLING MADISTMP DIRECTLY.
C
C USAGE:    CALL M_LSWAP (N,INDICES,ARRAY)
C
C   INPUT ARGUMENT LIST:
C     N        - I       NUMBER OF ARRAY ELEMENTS
C     INDICES  - IA      ARRAY OF INDICES
C
C   INPUT/OUTPUT ARGUMENT LIST:
C     ARRAY    - LA      ARRAY TO BE REARRANGED
C
C SUBPROGRAMS CALLED:
C     NONE
C
C REMARKS:
C   SEE madistmp.f FOR AN EXPLANATION OF HOW TEMPORARY STORAGE
C   IS HANDLED (ALL ARRAYS NAMED *TMP*).
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE M_LSWAP(N,INDICES,ARRAY,TMP)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER N
      INTEGER INDICES(*)
      LOGICAL ARRAY(*)
      LOGICAL TMP(*)

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER I

C     ------------------------------------------------------------------
C     TEMPORARY STORAGE DEFINITIONS
C     ------------------------------------------------------------------

C     *****************************************************************
C     ******************* BEGIN OF M_LSWAP ****************************
C     *****************************************************************
      DO 1 I = 1, N

         TMP(I) = ARRAY(I)

 1    CONTINUE

      DO 2 I = 1, N

         ARRAY(I) = TMP(INDICES(I))

 2    CONTINUE

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
